@@ -39,7 +39,7 @@ class NullSession : public Cantor::Session
     void interrupt();
 
     Cantor::Expression* evaluateExpression(const QString& command, Cantor::Expression::FinishingBehavior behave);
-    Cantor::CompletionObject* completionFor(const QString& cmd);
+    Cantor::CompletionObject* completionFor(const QString& cmd, int index=-1);
 
   private slots:
     void expressionFinished();
